@@ -199,6 +199,7 @@ from ._jsii import *
 
 import monocdk
 import monocdk.aws_events
+import monocdk.aws_iam
 import monocdk.aws_lambda
 import monocdk.aws_s3
 import monocdk.aws_sqs
@@ -245,7 +246,8 @@ class ServerlessClamscan(
         scope: monocdk.Construct,
         id: builtins.str,
         *,
-        buckets: typing.Optional[typing.Sequence[monocdk.aws_s3.Bucket]] = None,
+        accept_responsibility_for_using_imported_bucket: typing.Optional[builtins.bool] = None,
+        buckets: typing.Optional[typing.Sequence[monocdk.aws_s3.IBucket]] = None,
         defs_bucket_access_logs_config: typing.Optional["ServerlessClamscanLoggingProps"] = None,
         efs_encryption: typing.Optional[builtins.bool] = None,
         on_error: typing.Optional[monocdk.aws_lambda.IDestination] = None,
@@ -256,6 +258,7 @@ class ServerlessClamscan(
 
         :param scope: The parent creating construct (usually ``this``).
         :param id: The construct's name.
+        :param accept_responsibility_for_using_imported_bucket: Allows the use of imported buckets. When using imported buckets the user is responsible for adding the required policy statement to the bucket policy: ``getPolicyStatementForBucket()`` can be used to retrieve the policy statement required by the solution.
         :param buckets: An optional list of S3 buckets to configure for ClamAV Virus Scanning; buckets can be added later by calling addSourceBucket.
         :param defs_bucket_access_logs_config: Whether or not to enable Access Logging for the Virus Definitions bucket, you can specify an existing bucket and prefix (Default: Creates a new S3 Bucket for access logs ).
         :param efs_encryption: Whether or not to enable encryption on EFS filesystem (Default: enabled).
@@ -264,6 +267,7 @@ class ServerlessClamscan(
         :param reserved_concurrency: Optionally set a reserved concurrency for the virus scanning Lambda.
         '''
         props = ServerlessClamscanProps(
+            accept_responsibility_for_using_imported_bucket=accept_responsibility_for_using_imported_bucket,
             buckets=buckets,
             defs_bucket_access_logs_config=defs_bucket_access_logs_config,
             efs_encryption=efs_encryption,
@@ -275,7 +279,7 @@ class ServerlessClamscan(
         jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="addSourceBucket")
-    def add_source_bucket(self, bucket: monocdk.aws_s3.Bucket) -> None:
+    def add_source_bucket(self, bucket: monocdk.aws_s3.IBucket) -> None:
         '''Sets the specified S3 Bucket as a s3:ObjectCreate* for the ClamAV function.
 
         Grants the ClamAV function permissions to get and tag objects.
@@ -285,6 +289,19 @@ class ServerlessClamscan(
         '''
         return typing.cast(None, jsii.invoke(self, "addSourceBucket", [bucket]))
 
+    @jsii.member(jsii_name="getPolicyStatementForBucket")
+    def get_policy_statement_for_bucket(
+        self,
+        bucket: monocdk.aws_s3.IBucket,
+    ) -> monocdk.aws_iam.PolicyStatement:
+        '''Returns the statement that should be added to the bucket policy in order to prevent objects to be accessed when they are not clean or there have been scanning errors: this policy should be added manually if external buckets are passed to addSourceBucket().
+
+        :param bucket: The bucket which you need to protect with the policy.
+
+        :return: PolicyStatement the policy statement if available
+        '''
+        return typing.cast(monocdk.aws_iam.PolicyStatement, jsii.invoke(self, "getPolicyStatementForBucket", [bucket]))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="errorDest")
     def error_dest(self) -> monocdk.aws_lambda.IDestination:
@@ -297,6 +314,14 @@ class ServerlessClamscan(
         '''The Lambda Destination for completed ClamAV scans [CLEAN, INFECTED].'''
         return typing.cast(monocdk.aws_lambda.IDestination, jsii.get(self, "resultDest"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="scanAssumedPrincipal")
+    def scan_assumed_principal(self) -> monocdk.aws_iam.ArnPrincipal:
+        '''
+        :return: ArnPrincipal the ARN of the assumed role principal for the scan function
+        '''
+        return typing.cast(monocdk.aws_iam.ArnPrincipal, jsii.get(self, "scanAssumedPrincipal"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cleanRule")
     def clean_rule(self) -> typing.Optional[monocdk.aws_events.Rule]:
@@ -333,6 +358,12 @@ class ServerlessClamscan(
         '''Conditional: The Event Bridge Bus for completed ClamAV scans if a success (onResult) destination was not specified.'''
         return typing.cast(typing.Optional[monocdk.aws_events.EventBus], jsii.get(self, "resultBus"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="useImportedBuckets")
+    def use_imported_buckets(self) -> typing.Optional[builtins.bool]:
+        '''Conditional: When true, the user accepted the responsibility for using imported buckets.'''
+        return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "useImportedBuckets"))
+
 
 @jsii.data_type(
     jsii_type="monocdk-serverless-clamscan.ServerlessClamscanLoggingProps",
@@ -387,6 +418,7 @@ class ServerlessClamscanLoggingProps:
     jsii_type="monocdk-serverless-clamscan.ServerlessClamscanProps",
     jsii_struct_bases=[],
     name_mapping={
+        "accept_responsibility_for_using_imported_bucket": "acceptResponsibilityForUsingImportedBucket",
         "buckets": "buckets",
         "defs_bucket_access_logs_config": "defsBucketAccessLogsConfig",
         "efs_encryption": "efsEncryption",
@@ -399,7 +431,8 @@ class ServerlessClamscanProps:
     def __init__(
         self,
         *,
-        buckets: typing.Optional[typing.Sequence[monocdk.aws_s3.Bucket]] = None,
+        accept_responsibility_for_using_imported_bucket: typing.Optional[builtins.bool] = None,
+        buckets: typing.Optional[typing.Sequence[monocdk.aws_s3.IBucket]] = None,
         defs_bucket_access_logs_config: typing.Optional[ServerlessClamscanLoggingProps] = None,
         efs_encryption: typing.Optional[builtins.bool] = None,
         on_error: typing.Optional[monocdk.aws_lambda.IDestination] = None,
@@ -408,6 +441,7 @@ class ServerlessClamscanProps:
     ) -> None:
         '''Interface for creating a ServerlessClamscan.
 
+        :param accept_responsibility_for_using_imported_bucket: Allows the use of imported buckets. When using imported buckets the user is responsible for adding the required policy statement to the bucket policy: ``getPolicyStatementForBucket()`` can be used to retrieve the policy statement required by the solution.
         :param buckets: An optional list of S3 buckets to configure for ClamAV Virus Scanning; buckets can be added later by calling addSourceBucket.
         :param defs_bucket_access_logs_config: Whether or not to enable Access Logging for the Virus Definitions bucket, you can specify an existing bucket and prefix (Default: Creates a new S3 Bucket for access logs ).
         :param efs_encryption: Whether or not to enable encryption on EFS filesystem (Default: enabled).
@@ -418,6 +452,8 @@ class ServerlessClamscanProps:
         if isinstance(defs_bucket_access_logs_config, dict):
             defs_bucket_access_logs_config = ServerlessClamscanLoggingProps(**defs_bucket_access_logs_config)
         self._values: typing.Dict[str, typing.Any] = {}
+        if accept_responsibility_for_using_imported_bucket is not None:
+            self._values["accept_responsibility_for_using_imported_bucket"] = accept_responsibility_for_using_imported_bucket
         if buckets is not None:
             self._values["buckets"] = buckets
         if defs_bucket_access_logs_config is not None:
@@ -432,13 +468,24 @@ class ServerlessClamscanProps:
             self._values["reserved_concurrency"] = reserved_concurrency
 
     @builtins.property
-    def buckets(self) -> typing.Optional[typing.List[monocdk.aws_s3.Bucket]]:
+    def accept_responsibility_for_using_imported_bucket(
+        self,
+    ) -> typing.Optional[builtins.bool]:
+        '''Allows the use of imported buckets.
+
+        When using imported buckets the user is responsible for adding the required policy statement to the bucket policy: ``getPolicyStatementForBucket()`` can be used to retrieve the policy statement required by the solution.
+        '''
+        result = self._values.get("accept_responsibility_for_using_imported_bucket")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def buckets(self) -> typing.Optional[typing.List[monocdk.aws_s3.IBucket]]:
         '''An optional list of S3 buckets to configure for ClamAV Virus Scanning;
 
         buckets can be added later by calling addSourceBucket.
         '''
         result = self._values.get("buckets")
-        return typing.cast(typing.Optional[typing.List[monocdk.aws_s3.Bucket]], result)
+        return typing.cast(typing.Optional[typing.List[monocdk.aws_s3.IBucket]], result)
 
     @builtins.property
     def defs_bucket_access_logs_config(
